# Generated by Django 4.2.1 on 2023-07-07 19:32

from django.db import migrations

import edc_identifier.managers
import edc_sites.models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_offstudy", "0017_alter_subjectoffstudy_options"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="subjectoffstudy",
            managers=[
                ("objects", edc_identifier.managers.SubjectIdentifierManager()),
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
    ]
